summaryrefslogtreecommitdiff
path: root/include/ruby/backward/2/long_long.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/backward/2/long_long.h')
-rw-r--r--include/ruby/backward/2/long_long.h41
1 files changed, 25 insertions, 16 deletions
diff --git a/include/ruby/backward/2/long_long.h b/include/ruby/backward/2/long_long.h
index 8669d42cd6..8e6b2743fc 100644
--- a/include/ruby/backward/2/long_long.h
+++ b/include/ruby/backward/2/long_long.h
@@ -1,11 +1,13 @@
-/** \noop-*-C++-*-vi:ft=cpp
+#ifndef RUBY_BACKWARD2_LONG_LONG_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RUBY_BACKWARD2_LONG_LONG_H
+/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
* @copyright This file is a part of the programming language Ruby.
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -15,7 +17,7 @@
* recursively included from extension libraries written in C++.
* Do not expect for instance `__VA_ARGS__` is always available.
* We assume C99 for ruby itself but we don't assume languages of
- * extension libraries. They could be written in C++98.
+ * extension libraries. They could be written in C++98.
* @brief Defines old #LONG_LONG
*
* No known compiler that can compile today's ruby lacks long long.
@@ -23,28 +25,33 @@
* while ago (some time back in 2013). The macros are for backwards
* compatibility only.
*/
-#include "ruby/3/config.h"
-#include "ruby/3/has/warning.h"
-#include "ruby/3/warning_push.h"
+#include "ruby/internal/config.h"
+#include "ruby/internal/has/warning.h"
+#include "ruby/internal/warning_push.h"
-#if defined(LONG_LONG)
-# /* Take that. */
+#if defined(__DOXYGEN__)
+# /** @cond INTERNAL_MACRO */
+# define HAVE_LONG_LONG 1
+# define HAVE_TRUE_LONG_LONG 1
+# /** @endcond */
+# /** @deprecated Just use `long long` directly. */
+# define LONG_LONG long long.
-#elif RUBY3_HAS_WARNING("-Wc++11-long-long")
+#elif RBIMPL_HAS_WARNING("-Wc++11-long-long")
# define HAVE_TRUE_LONG_LONG 1
# define LONG_LONG \
- RUBY3_WARNING_PUSH() \
- RUBY3_WARNING_IGNORED(-Wc++11-long-long) \
+ RBIMPL_WARNING_PUSH() \
+ RBIMPL_WARNING_IGNORED(-Wc++11-long-long) \
long long \
- RUBY3_WARNING_POP()
+ RBIMPL_WARNING_POP()
-#elif RUBY3_HAS_WARNING("-Wlong-long")
+#elif RBIMPL_HAS_WARNING("-Wlong-long")
# define HAVE_TRUE_LONG_LONG 1
# define LONG_LONG \
- RUBY3_WARNING_PUSH() \
- RUBY3_WARNING_IGNORED(-Wlong-long) \
+ RBIMPL_WARNING_PUSH() \
+ RBIMPL_WARNING_IGNORED(-Wlong-long) \
long long \
- RUBY3_WARNING_POP()
+ RBIMPL_WARNING_POP()
#elif defined(HAVE_LONG_LONG)
# define HAVE_TRUE_LONG_LONG 1
@@ -62,3 +69,5 @@
# error Remember to attach a detailed description of your environment.
# error Thank you!
#endif
+
+#endif /* RBIMPL_BACKWARD2_LONG_LONG_H */
@@ -1,11 +1,13 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `rbimpl` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file